Class: BiDiGenerate::Event Private
- Inherits:
-
Struct
- Object
- Struct
- BiDiGenerate::Event
- Defined in:
- lib/selenium/webdriver/bidi/support/bidi_generate.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
payload_ref is the Protocol-relative class the event's params parse into (nil when non-structured, dispatched raw) — the inbound counterpart to a command's result_ref.
Instance Attribute Summary collapse
-
#event_name ⇒ Object
Returns the value of attribute event_name.
-
#payload_ref ⇒ Object
Returns the value of attribute payload_ref.
-
#wire_name ⇒ Object
Returns the value of attribute wire_name.
Instance Method Summary collapse
-
#type_entry ⇒ Object
private
An EVENT_TYPES entry mapping the wire method to the type its params parse into.
Instance Attribute Details
#event_name ⇒ Object
Returns the value of attribute event_name
227 228 229 |
# File 'lib/selenium/webdriver/bidi/support/bidi_generate.rb', line 227 def event_name @event_name end |
#payload_ref ⇒ Object
Returns the value of attribute payload_ref
227 228 229 |
# File 'lib/selenium/webdriver/bidi/support/bidi_generate.rb', line 227 def payload_ref @payload_ref end |
#wire_name ⇒ Object
Returns the value of attribute wire_name
227 228 229 |
# File 'lib/selenium/webdriver/bidi/support/bidi_generate.rb', line 227 def wire_name @wire_name end |
Instance Method Details
#type_entry ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
An EVENT_TYPES entry mapping the wire method to the type its params parse into.
229 |
# File 'lib/selenium/webdriver/bidi/support/bidi_generate.rb', line 229 def type_entry = "'#{wire_name}' => #{payload_ref || 'nil'}" |