Method: Selenium::Client::GeneratedDriver#capture_entire_page_screenshot_to_string
- Defined in:
- lib/selenium/client/legacy_driver.rb
#capture_entire_page_screenshot_to_string(kwargs) ⇒ Object
Downloads a screenshot of the browser current window canvas to a based 64 encoded PNG file. The entire windows canvas is captured, including parts rendered outside of the current view port.
Currently this only works in Mozilla and when running in chrome mode.
‘kwargs’ is A kwargs string that modifies the way the screenshot is captured. Example: “background=#CCFFDD”. This may be useful to set for capturing screenshots of less-than-ideal layouts, for example where absolute positioning causes the calculation of the canvas dimension to fail and a black background is exposed (possibly obscuring black text).
1658 1659 1660 |
# File 'lib/selenium/client/legacy_driver.rb', line 1658 def capture_entire_page_screenshot_to_string(kwargs) return string_command("captureEntirePageScreenshotToString", [kwargs,]) end |