Method: Selenium::Client::GeneratedDriver#delete_all_visible_cookies

Defined in:
lib/selenium/client/legacy_driver.rb

#delete_all_visible_cookiesObject

Calls deleteCookie with recurse=true on all cookies visible to the current page. As noted on the documentation for deleteCookie, recurse=true can be much slower than simply deleting the cookies using a known domain/path.



1501
1502
1503
# File 'lib/selenium/client/legacy_driver.rb', line 1501

def delete_all_visible_cookies()
    remote_control_command("deleteAllVisibleCookies", [])
end