Method: Selenium::Client::GeneratedDriver#drag_and_drop

Defined in:
lib/selenium/client/legacy_driver.rb

#drag_and_drop(locator, movementsString) ⇒ Object

Drags an element a certain distance and then drops it

‘locator’ is an element locator ‘movementsString’ is offset in pixels from the current location to which the element should be moved, e.g., “+70,-300”



1185
1186
1187
# File 'lib/selenium/client/legacy_driver.rb', line 1185

def drag_and_drop(locator,movementsString)
    remote_control_command("dragAndDrop", [locator,movementsString,])
end