Method: Selenium::Client::GeneratedDriver#get_confirmation

Defined in:
lib/selenium/client/legacy_driver.rb

#get_confirmationObject

Retrieves the message of a JavaScript confirmation dialog generated during the previous action.

By default, the confirm function will return true, having the same effect as manually clicking OK. This can be changed by prior execution of the chooseCancelOnNextConfirmation command.

If an confirmation is generated but you do not consume it with getConfirmation, the next Selenium action will fail.

NOTE: under Selenium, JavaScript confirmations will NOT pop up a visible dialog.

NOTE: Selenium does NOT support JavaScript confirmations that are generated in a page’s onload() event handler. In this case a visible dialog WILL be generated and Selenium will hang until you manually click OK.



879
880
881
# File 'lib/selenium/client/legacy_driver.rb', line 879

def get_confirmation()
    return string_command("getConfirmation", [])
end