Method: Selenium::Client::GeneratedDriver#get_cookie_by_name

Defined in:
lib/selenium/client/legacy_driver.rb

Returns the value of the cookie with the specified name, or throws an error if the cookie is not present.

‘name’ is the name of the cookie



1456
1457
1458
# File 'lib/selenium/client/legacy_driver.rb', line 1456

def get_cookie_by_name(name)
    return string_command("getCookieByName", [name,])
end