Method: Selenium::Client::GeneratedDriver#get_prompt

Defined in:
lib/selenium/client/legacy_driver.rb

#get_promptObject

Retrieves the message of a JavaScript question prompt dialog generated during the previous action.

Successful handling of the prompt requires prior execution of the answerOnNextPrompt command. If a prompt is generated but you do not get/verify it, the next Selenium action will fail. NOTE: under Selenium, JavaScript prompts will NOT pop up a visible dialog. NOTE: Selenium does NOT support JavaScript prompts that are generated in a page’s onload() event handler. In this case a visible dialog WILL be generated and Selenium will hang until someone manually clicks OK.



897
898
899
# File 'lib/selenium/client/legacy_driver.rb', line 897

def get_prompt()
    return string_command("getPrompt", [])
end