Method: Selenium::Client::GeneratedDriver#select_frame

Defined in:
lib/selenium/client/legacy_driver.rb

#select_frame(locator) ⇒ Object

Selects a frame within the current window. (You may invoke this command multiple times to select nested frames.) To select the parent frame, use “relative=parent” as a locator; to select the top frame, use “relative=top”. You can also select a frame by its 0-based index number; select the first frame with “index=0”, or the third frame with “index=2”.

You may also use a DOM expression to identify the frame you want directly, like this: dom=frames["main"].frames["subframe"]

‘locator’ is an element locator identifying a frame or iframe



682
683
684
# File 'lib/selenium/client/legacy_driver.rb', line 682

def select_frame(locator)
    remote_control_command("selectFrame", [locator,])
end