Method: Selenium::Client::GeneratedDriver#set_context

Defined in:
lib/selenium/client/legacy_driver.rb

#set_context(context) ⇒ Object

Writes a message to the status bar and adds a note to the browser-side log.

‘context’ is the message to be sent to the browser



1622
1623
1624
# File 'lib/selenium/client/legacy_driver.rb', line 1622

def set_context(context)
    remote_control_command("setContext", [context,])
end