Method: Selenium::Client::GeneratedDriver#shut_down_selenium_server

Defined in:
lib/selenium/client/legacy_driver.rb

#shut_down_selenium_serverObject

Kills the running Selenium Server and all browser sessions. After you run this command, you will no longer be able to send commands to the server; you can’t remotely start the server once it has been stopped. Normally you should prefer to run the “stop” command, which terminates the current browser session, rather than shutting down the entire server.



1668
1669
1670
# File 'lib/selenium/client/legacy_driver.rb', line 1668

def shut_down_selenium_server()
    remote_control_command("shutDownSeleniumServer", [])
end