Method: Selenium::WebDriver::DriverExtensions::HasContext#context=

Defined in:
lib/selenium/webdriver/common/driver_extensions/has_context.rb

#context=(value) ⇒ Object

Sets the context that Selenium commands are running in using

a `with` statement. The state of the context on the server is
saved before entering the block, and restored upon exiting it.

Parameters:

  • value (String)

    which context gets set (either ‘chrome’ or ‘content’)



32
33
34
# File 'lib/selenium/webdriver/common/driver_extensions/has_context.rb', line 32

def context=(value)
  @bridge.context = value
end