Method: Selenium::WebDriver::SearchContext#find_element

Defined in:
lib/selenium/webdriver/common/search_context.rb

#find_element(*args) ⇒ WebDriver::Element

Find the first element matching the given arguments.

When using Element#find_element with :xpath, be aware that webdriver follows standard conventions: a search prefixed with “//” will search the entire document, not just the children of this current node. Use “.//” to limit your search to the children of the receiving Element.

Parameters:

  • how (:class, :class_name, :id, :link_text, :link, :partial_link_text, :name, :tag_name, :xpath)
  • what (String)

Returns:

Raises:

  • (NoSuchElementError)

    if the element doesn’t exist



34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/selenium/webdriver/common/search_context.rb', line 34

def find_element(*args)
  how, what = extract_args(args)

  unless by = FINDERS[how.to_sym]
    raise ArgumentError, "cannot find element by #{how.inspect}"
  end

  meth = "findElementBy#{by}"
  what = what.to_s

  bridge.send meth, ref, what
end