Class: Selenium::WebDriver::Remote::Capabilities Private

Inherits:
Object
  • Object
show all
Defined in:
lib/selenium/webdriver/remote/capabilities.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Specification of the desired and/or actual capabilities of the browser that the server is being asked to create.

API:

  • private

Constant Summary collapse

DEFAULTS =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

API:

  • private

{
  :browser_name          => "",
  :version               => "",
  :platform              => :any,
  :javascript_enabled    => false,
  :css_selectors_enabled => false,
  :takes_screenshot      => false,
  :native_events         => false,
  :rotatable             => false,
  :firefox_profile       => nil,
  :proxy                 => nil
}

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(opts = {}) ⇒ Capabilities

Firefox-specific options:

Parameters:

  • a customizable set of options

  • a customizable set of options

  • a customizable set of options

  • a customizable set of options

  • a customizable set of options

  • a customizable set of options

  • a customizable set of options

  • a customizable set of options

  • a customizable set of options

API:

  • public



179
180
181
182
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 179

def initialize(opts = {})
  @capabilities = DEFAULTS.merge(opts)
  self.proxy    = opts.delete(:proxy)
end

Class Method Details

.android(opts = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



44
45
46
47
48
49
50
51
52
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 44

def android(opts = {})
  new({
    :browser_name       => "android",
    :platform           => :android,
    :javascript_enabled => true,
    :rotatable          => true,
    :takes_screenshot   => true
  }.merge(opts))
end

.chrome(opts = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



54
55
56
57
58
59
60
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 54

def chrome(opts = {})
  new({
    :browser_name          => "chrome",
    :javascript_enabled    => true,
    :css_selectors_enabled => true
  }.merge(opts))
end

.firefox(opts = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



62
63
64
65
66
67
68
69
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 62

def firefox(opts = {})
  new({
    :browser_name          => "firefox",
    :javascript_enabled    => true,
    :takes_screenshot      => true,
    :css_selectors_enabled => true
  }.merge(opts))
end

.htmlunit(opts = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



71
72
73
74
75
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 71

def htmlunit(opts = {})
  new({
    :browser_name => "htmlunit"
  }.merge(opts))
end

.htmlunitwithjs(opts = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



77
78
79
80
81
82
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 77

def htmlunitwithjs(opts = {})
  new({
    :browser_name => "htmlunit",
    :javascript_enabled => true
  }.merge(opts))
end

.internet_explorer(opts = {}) ⇒ Object Also known as: ie

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



84
85
86
87
88
89
90
91
92
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 84

def internet_explorer(opts = {})
  new({
    :browser_name          => "internet explorer",
    :platform              => :windows,
    :takes_screenshot      => true,
    :css_selectors_enabled => true,
    :native_events         => true
  }.merge(opts))
end

.ipad(opts = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



103
104
105
106
107
108
109
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 103

def ipad(opts = {})
  new({
    :browser_name       => "iPad",
    :platform           => :mac,
    :javascript_enabled => true
  }.merge(opts))
end

.iphone(opts = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



95
96
97
98
99
100
101
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 95

def iphone(opts = {})
  new({
    :browser_name       => "iPhone",
    :platform           => :mac,
    :javascript_enabled => true
  }.merge(opts))
end

.json_create(data) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 142

def json_create(data)
  data = data.dup

  caps = new
  caps.browser_name          = data.delete("browserName")
  caps.version               = data.delete("version")
  caps.platform              = data.delete("platform").downcase.to_sym if data.has_key?('platform')
  caps.javascript_enabled    = data.delete("javascriptEnabled")
  caps.css_selectors_enabled = data.delete("cssSelectorsEnabled")
  caps.takes_screenshot      = data.delete("takesScreenshot")
  caps.native_events         = data.delete("nativeEvents")
  caps.rotatable             = data.delete("rotatable")
  caps.proxy                 = Proxy.json_create(data['proxy']) if data.has_key?('proxy')

  # any remaining pairs will be added as is, with no conversion
  caps.merge!(data)

  caps
end

.opera(opts = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



111
112
113
114
115
116
117
118
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 111

def opera(opts = {})
  new({
    :browser_name          => "opera",
    :javascript_enabled    => true,
    :takes_screenshot      => true,
    :css_selectors_enabled => true
  }.merge(opts))
end

.phantomjs(opts = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



120
121
122
123
124
125
126
127
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 120

def phantomjs(opts = {})
  new({
    :browser_name          => "phantomjs",
    :javascript_enabled    => true,
    :takes_screenshot      => true,
    :css_selectors_enabled => true
  }.merge(opts))
end

.safari(opts = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



129
130
131
132
133
134
135
136
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 129

def safari(opts = {})
  new({
    :browser_name          => "safari",
    :javascript_enabled    => true,
    :takes_screenshot      => true,
    :css_selectors_enabled => true
  }.merge(opts))
end

Instance Method Details

#==(other) ⇒ Object Also known as: eql?

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



247
248
249
250
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 247

def ==(other)
  return false unless other.kind_of? self.class
  as_json == other.as_json
end

#[](key) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



192
193
194
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 192

def [](key)
  @capabilities[key]
end

#[]=(key, value) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Allows setting arbitrary capabilities.

API:

  • private



188
189
190
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 188

def []=(key, value)
  @capabilities[key] = value
end

#as_json(opts = nil) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 220

def as_json(opts = nil)
  hash = {}

  @capabilities.each do |key, value|
    case key
    when :platform
      hash['platform'] = value.to_s.upcase
    when :firefox_profile
      hash['firefox_profile'] = value.as_json['zip'] if value
    when :proxy
      hash['proxy'] = value.as_json if value
    when String, :firefox_binary
      hash[key.to_s] = value
    when Symbol
      hash[camel_case(key.to_s)] = value
    else
      raise TypeError, "expected String or Symbol, got #{key.inspect}:#{key.class} / #{value.inspect}"
    end
  end

  hash
end

#merge!(other) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



196
197
198
199
200
201
202
203
204
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 196

def merge!(other)
  if other.respond_to?(:capabilities, true) && other.capabilities.kind_of?(Hash)
    @capabilities.merge! other.capabilities
  elsif other.kind_of? Hash
    @capabilities.merge! other
  else
    raise ArgumentError, "argument should be a Hash or implement #capabilities"
  end
end

#proxy=(proxy) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



206
207
208
209
210
211
212
213
214
215
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 206

def proxy=(proxy)
  case proxy
  when Hash
    @capabilities[:proxy] = Proxy.new(proxy)
  when Proxy, nil
    @capabilities[:proxy] = proxy
  else
    raise TypeError, "expected Hash or #{Proxy.name}, got #{proxy.inspect}:#{proxy.class}"
  end
end

#to_json(*args) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



243
244
245
# File 'lib/selenium/webdriver/remote/capabilities.rb', line 243

def to_json(*args)
  WebDriver.json_dump as_json
end