Method: Selenium::Client::GeneratedDriver#answer_on_next_prompt
- Defined in:
- lib/selenium/client/legacy_driver.rb
#answer_on_next_prompt(answer) ⇒ Object
Instructs Selenium to return the specified answer string in response to the next JavaScript prompt [window.prompt()].
‘answer’ is the answer to give in response to the prompt pop-up
775 776 777 |
# File 'lib/selenium/client/legacy_driver.rb', line 775 def answer_on_next_prompt(answer) remote_control_command("answerOnNextPrompt", [answer,]) end |