Method: Selenium::Client::GeneratedDriver#assign_id
- Defined in:
- lib/selenium/client/legacy_driver.rb
#assign_id(locator, identifier) ⇒ Object
Temporarily sets the “id” attribute of the specified element, so you can locate it in the future using its ID rather than a slow/complicated XPath. This ID will disappear once the page is reloaded.
‘locator’ is an element locator pointing to an element ‘identifier’ is a string to be used as the ID of the specified element
1352 1353 1354 |
# File 'lib/selenium/client/legacy_driver.rb', line 1352 def assign_id(locator,identifier) remote_control_command("assignId", [locator,identifier,]) end |