Method: Selenium::Client::GeneratedDriver#double_click
- Defined in:
- lib/selenium/client/legacy_driver.rb
#double_click(locator) ⇒ Object
Double clicks on a link, button, checkbox or radio button. If the double click action causes a new page to load (like a link usually does), call waitForPageToLoad.
‘locator’ is an element locator
154 155 156 |
# File 'lib/selenium/client/legacy_driver.rb', line 154 def double_click(locator) remote_control_command("doubleClick", [locator,]) end |