Method: Selenium::Client::GeneratedDriver#double_click_at
- Defined in:
- lib/selenium/client/legacy_driver.rb
#double_click_at(locator, coordString) ⇒ Object
Doubleclicks on a link, button, checkbox or radio button. If the action causes a new page to load (like a link usually does), call waitForPageToLoad.
‘locator’ is an element locator ‘coordString’ is specifies the x,y position (i.e. - 10,20) of the mouse event relative to the element returned by the locator.
184 185 186 |
# File 'lib/selenium/client/legacy_driver.rb', line 184 def double_click_at(locator,coordString) remote_control_command("doubleClickAt", [locator,coordString,]) end |