Method: Selenium::Client::GeneratedDriver#mouse_down_at
- Defined in:
- lib/selenium/client/legacy_driver.rb
#mouse_down_at(locator, coordString) ⇒ Object
Simulates a user pressing the left mouse button (without releasing it yet) at the specified location.
‘locator’ is an element locator ‘coordString’ is specifies the x,y position (i.e. - 10,20) of the mouse event relative to the element returned by the locator.
338 339 340 |
# File 'lib/selenium/client/legacy_driver.rb', line 338 def mouse_down_at(locator,coordString) remote_control_command("mouseDownAt", [locator,coordString,]) end |