Method: Selenium::Client::GeneratedDriver#mouse_down_right_at
- Defined in:
- lib/selenium/client/legacy_driver.rb
#mouse_down_right_at(locator, coordString) ⇒ Object
Simulates a user pressing the right mouse button (without releasing it yet) at the specified location.
‘locator’ is an element locator ‘coordString’ is specifies the x,y position (i.e. - 10,20) of the mouse event relative to the element returned by the locator.
348 349 350 |
# File 'lib/selenium/client/legacy_driver.rb', line 348 def mouse_down_right_at(locator,coordString) remote_control_command("mouseDownRightAt", [locator,coordString,]) end |