Method: Selenium::Client::GeneratedDriver#mouse_up_at
- Defined in:
- lib/selenium/client/legacy_driver.rb
#mouse_up_at(locator, coordString) ⇒ Object
Simulates the event that occurs when the user releases the mouse button (i.e., stops holding the button down) at the specified location.
‘locator’ is an element locator ‘coordString’ is specifies the x,y position (i.e. - 10,20) of the mouse event relative to the element returned by the locator.
376 377 378 |
# File 'lib/selenium/client/legacy_driver.rb', line 376 def mouse_up_at(locator,coordString) remote_control_command("mouseUpAt", [locator,coordString,]) end |