Method: Selenium::Client::GeneratedDriver#retrieve_last_remote_control_logs
- Defined in:
- lib/selenium/client/legacy_driver.rb
#retrieve_last_remote_control_logs ⇒ Object
Retrieve the last messages logged on a specific remote control. Useful for error reports, especially when running multiple remote controls in a distributed environment. The maximum number of log messages that can be retrieve is configured on remote control startup.
1677 1678 1679 |
# File 'lib/selenium/client/legacy_driver.rb', line 1677 def retrieve_last_remote_control_logs() return string_command("retrieveLastRemoteControlLogs", []) end |