Method: Selenium::Client::GeneratedDriver#set_timeout
- Defined in:
- lib/selenium/client/legacy_driver.rb
#set_timeout(timeout) ⇒ Object
Specifies the amount of time that Selenium will wait for actions to complete.
Actions that require waiting include “open” and the “waitFor*” actions.
The default timeout is 30 seconds.
‘timeout’ is a timeout in milliseconds, after which the action will return with an error
1410 1411 1412 |
# File 'lib/selenium/client/legacy_driver.rb', line 1410 def set_timeout(timeout) remote_control_command("setTimeout", [timeout,]) end |