Method: Selenium::WebDriver::Logger#io
- Defined in:
- lib/selenium/webdriver/common/logger.rb
#io ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns IO object used by logger internally.
Normally, we would have never needed it, but we want to use it as IO object for all child processes to ensure their output is redirected there.
It is only used in debug level, in other cases output is suppressed.
116 117 118 |
# File 'lib/selenium/webdriver/common/logger.rb', line 116 def io @logger.instance_variable_get(:@logdev).dev end |