Method: Selenium::WebDriver::WheelActions#scroll_to
- Defined in:
- lib/selenium/webdriver/common/interactions/wheel_actions.rb
#scroll_to(element, device: nil) ⇒ Selenium::WebDriver::WheelActions
If the element is outside the viewport, scrolls the bottom of the element to the bottom of the viewport.
44 45 46 |
# File 'lib/selenium/webdriver/common/interactions/wheel_actions.rb', line 44 def scroll_to(element, device: nil) scroll(origin: element, device: device) end |