Method: Selenium::Client::GeneratedDriver#remove_script
- Defined in:
- lib/selenium/client/legacy_driver.rb
#remove_script(scriptTagId) ⇒ Object
Removes a script tag from the Selenium document identified by the given id. Does nothing if the referenced tag doesn’t exist.
‘scriptTagId’ is the id of the script element to remove.
1607 1608 1609 |
# File 'lib/selenium/client/legacy_driver.rb', line 1607 def remove_script(scriptTagId) remote_control_command("removeScript", [scriptTagId,]) end |