Class: Selenium::WebDriver::Remote::Http::Default Private

Inherits:
Common
  • Object
show all
Defined in:
lib/selenium/webdriver/remote/http/default.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

API:

  • private

Direct Known Subclasses

Persistent

Constant Summary

Constants inherited from Common

Common::CONTENT_TYPE, Common::DEFAULT_HEADERS, Common::MAX_REDIRECTS

Instance Attribute Summary collapse

Attributes inherited from Common

#timeout

Instance Method Summary collapse

Methods inherited from Common

#call, #close, #quit_errors

Constructor Details

#initialize(open_timeout: nil, read_timeout: nil) ⇒ Default

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Initializes object. Warning: Setting #open_timeout to non-nil values will cause a separate thread to spawn. Debuggers that freeze the process will not be able to evaluate any operations if that happens.

Parameters:

  • (defaults to: nil)
    • Open timeout to apply to HTTP client.

  • (defaults to: nil)
    • Read timeout (seconds) to apply to HTTP client.

API:

  • private



39
40
41
42
# File 'lib/selenium/webdriver/remote/http/default.rb', line 39

def initialize(open_timeout: nil, read_timeout: nil)
  @open_timeout = open_timeout
  @read_timeout = read_timeout
end

Instance Attribute Details

#open_timeoutObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



31
32
33
# File 'lib/selenium/webdriver/remote/http/default.rb', line 31

def open_timeout
  @open_timeout
end

#proxy=(value) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



29
30
31
# File 'lib/selenium/webdriver/remote/http/default.rb', line 29

def proxy=(value)
  @proxy = value
end

#read_timeoutObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



32
33
34
# File 'lib/selenium/webdriver/remote/http/default.rb', line 32

def read_timeout
  @read_timeout
end

Instance Method Details

#timeout=(value) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.

Please set the specific desired timeout #read_timeout or #open_timeout directly.

Maintaining backward compatibility.

Parameters:

    • Timeout in seconds to apply to both open timeout and read timeouts.

API:

  • private



47
48
49
50
51
# File 'lib/selenium/webdriver/remote/http/default.rb', line 47

def timeout=(value)
  WebDriver.logger.deprecate ':timeout=', '#read_timeout= and #open_timeout='
  self.open_timeout = value
  self.read_timeout = value
end